EarthMC is a large Minecraft server this package lets you get info about things on that server.\
[Documentation](https://github.com/TheSuperGamer20578/EMC-info/wiki) **|** [Github](https://github.com/TheSuperGamer20578/EMC-info)